<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!function_exists('cmb2_print')) {

    function cmb2_print($input = NULL) {
        echo '<pre>';
        print_r($input);
        echo '</pre>';
    }

}

if (!function_exists('cmb2_admin_styles')) {

    function cmb2_admin_styles($instance) {
        echo '<style>';
        ?>
        .cmb-type-hidden{
        display:none;
        }
        <?php
        echo '</style>';
    }

    add_action('admin_print_styles-post.php', 'cmb2_admin_styles', 10, 1);
}

if (!function_exists('cmb2_render_disabled')) {

    function cmb2_render_disabled($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        if ($escaped_value) {
            echo '<span title="' . __('Defined automatically', 'green') . '">' . $escaped_value . '</span>';
        }
        echo $field_type_object->input(array('type' => 'hidden', 'desc' => '', 'class' => false));
    }

    add_action('cmb2_render_disabled', 'cmb2_render_disabled', 10, 5);
}

if (!function_exists('cmb2_render_value')) {

    function cmb2_render_value($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        $value = isset($field_type_object->field->args['value']) ? $field_type_object->field->args['value'] : NULL;
        if ($value != '') {
            if (is_array($value)) {
                echo '<ul>';
                foreach ($value as $sub_key => $sub_value) {
                    echo '<li><span title="' . __('Defined automatically', 'green') . '">' . urldecode($sub_key) . '</span></li>';
                }
                echo '</ul>';
            } else {
                echo '<span title="' . __('Defined automatically', 'green') . '">' . $value . '</span>';
            }
        }
        echo $field_type_object->input(array(
          'type' => 'hidden',
          'desc' => '',
          'class' => false,
          'value' => $value,
        ));
    }

    add_action('cmb2_render_value', 'cmb2_render_value', 10, 5);
}

if (!function_exists('cmb2_render_files')) {

    function cmb2_render_files($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        $files = isset($field_type_object->field->args['files']) ? $field_type_object->field->args['files'] : NULL;
        if ($files) {
            if (is_array($files)) {
                echo '<ul>';
                foreach ($files as $file_id) {
                    $url = wp_get_attachment_url($file_id);
                    if ($url) {
                        echo '<li><a href="' . $url . '" target="_blank" download="' . get_the_title($object_id) . '-' . $file_id . '">' . __('Download', 'green') . '</a></li>';
                    }
                }
                echo '</ul>';
            } else {
                
            }
        }
        echo $field_type_object->input(array(
          'type' => 'hidden',
          'desc' => '',
          'class' => false,
          'files' => $files,
        ));
    }

    add_action('cmb2_render_files', 'cmb2_render_files', 10, 5);
}

if (!function_exists('cmb2_render_print_array')) {

    function cmb2_render_print_array($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        $value = isset($field_type_object->field->value) ? $field_type_object->field->value : NULL;
        if ($value != '' && is_array($value)) {
            foreach ($value as $sub_key => $sub_value) {
                echo '<pre>';
                if (is_array($sub_value)) {
                    foreach ($sub_value as $subkey => $subvalue) {
                        print_r($sub_key . ' => ' . urldecode($subkey));
                        echo '<br/>';
                    }
                } else {
                    print_r($sub_key . ' => ' . $sub_value);
                }
                echo '</pre>';
            }
        } else {
            echo $value;
        }
    }

    add_action('cmb2_render_print_array', 'cmb2_render_print_array', 10, 5);
}

if (!function_exists('cmb2_render_display_array')) {

    function cmb2_render_display_array($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        $field_values = $field_type_object->field->value;
        if ($field_values && is_array($field_values)) {
            echo '<table>';
            foreach ($field_values as $key => $value) {
                echo '<tr>';
                echo '<td>';
                echo $key;
                echo '</td>';
                echo '<td>';
                echo $value;
                echo '</td>';
                echo '</tr>';
            }
            echo '</table>';
        }
    }

    add_action('cmb2_render_display_array', 'cmb2_render_display_array', 10, 5);
}

if (!function_exists('cmb2_render_export')) {

    function cmb2_render_export($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        if (isset($field_type_object->field->args['prefix'])) {
            $prefix = $field_type_object->field->args['prefix'];
        } else {
            $prefix = 'export';
        }
        echo '<a class="button button-primary" href="' . site_url() . '/wp-admin/post.php?post=' . $object_id . '&action=edit&' . $prefix . '" target="_blank">' . __('Export as CSV', 'green') . '</a>';
    }

    add_action('cmb2_render_export', 'cmb2_render_export', 10, 5);
}

if (!function_exists('cmb2_render_post_type_select')) {

    function cmb2_render_post_type_select($field, $escaped_value, $object_id, $object_type, $field_type_object) {

        $term = isset($field_type_object->field->args['term']) ? $field_type_object->field->args['term'] : NULL;
        $taxonomy = isset($field_type_object->field->args['taxonomy']) ? $field_type_object->field->args['taxonomy'] : NULL;
        $post_type = isset($field_type_object->field->args['post_type']) ? $field_type_object->field->args['post_type'] : NULL;

        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        if (is_plugin_active('event-organiser/event-organiser.php')) {
            $has_event = TRUE;
        } else {
            $has_event = FALSE;
        }

        $options = $field_type_object->select_option(
            array(
              'label' => __('Please choose from list', 'green'),
              'value' => '',
              'checked' => ''
            )
        );

        if (is_array($post_type)) {

            $args = array(
              $taxonomy => $term,
              'post_type' => $post_type,
              'order' => 'DESC',
              'orderby' => 'date',
              'event_start_after' => 'today',
              'showpastevents' => TRUE,
              'posts_per_page' => '-1',
              'numberposts' => '-1',
              'suppress_filters' => '0',
            );
            $items = get_posts($args);
            foreach ($items as $item) {
                if ($object_id == $item->ID) {
                    continue;
                }

                // Is event
                if ($item->post_type == 'event') {
                    if ($has_event) {
                        if (eo_reoccurs($item->ID)) {
                            continue;
                        }
                    } else {
                        $name = ( strlen($item->post_title) > 38 ) ? mb_substr($item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $item->post_title;
                        $selected = $escaped_value == $item->ID;
                        $options .= $field_type_object->select_option(
                            array(
                              'label' => $name,
                              'value' => $item->ID,
                              'checked' => $selected
                            )
                        );
                    }
                } else {
                    $name = ( strlen($item->post_title) > 38 ) ? mb_substr($item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $item->post_title;
                    $selected = $escaped_value == $item->ID;
                    $options .= $field_type_object->select_option(
                        array(
                          'label' => $name,
                          'value' => $item->ID,
                          'checked' => $selected
                        )
                    );
                }
            }
        } else {

            if (is_post_type_hierarchical($post_type)) {
                $args = array(
                  'post_type' => $post_type,
                  'order' => 'ASC',
                  'orderby' => 'menu_order, title',
                  'posts_per_page' => '-1',
                  'suppress_filters' => '0',
                  'post_parent' => '0'
                );
            } else {
                $args = array(
                  'post_type' => $post_type,
                  'order' => 'DESC',
                  'orderby' => 'date',
                  'event_start_after' => 'today',
                  'showpastevents' => TRUE,
                  $taxonomy => $term,
                  'posts_per_page' => '-1',
                  'numberposts' => '-1',
                  'suppress_filters' => '0',
                );
            }
            $items = get_posts($args);

            if (is_post_type_hierarchical($post_type)) {
                foreach ($items as $item) {

                    $name = ( strlen($item->post_title) > 38 ) ? mb_substr($item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $item->post_title;
                    $selected = $escaped_value == $item->ID;
                    $options .= $field_type_object->select_option(
                        array(
                          'label' => $name,
                          'value' => $item->ID,
                          'checked' => $selected
                        )
                    );

                    $args = array(
                      'post_type' => $post_type,
                      'order' => 'ASC',
                      'orderby' => 'menu_order',
                      'posts_per_page' => '-1',
                      'suppress_filters' => '0',
                      'post_parent' => $item->ID
                    );
                    $sub_items = get_posts($args);
                    if ($sub_items) {
                        foreach ($sub_items as $sub_item) {
                            $name = ( strlen($sub_item->post_title) > 38 ) ? mb_substr($sub_item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $sub_item->post_title;
                            $selected = $escaped_value == $sub_item->ID;
                            $options .= $field_type_object->select_option(
                                array(
                                  'label' => '- ' . $name,
                                  'value' => $sub_item->ID,
                                  'checked' => $selected
                                )
                            );
                        }
                    }
                }
            } else {
                foreach ($items as $item) {
                    if ($object_id == $item->ID) {
                        continue;
                    }

                    // Is event
                    if ($item->post_type == 'event') {
                        if ($has_event) {
                            if (eo_reoccurs($item->ID)) {
                                continue;
                            }
                        } else {
                            $name = ( strlen($item->post_title) > 38 ) ? mb_substr($item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $item->post_title;
                            $selected = $escaped_value == $item->ID;
                            $options .= $field_type_object->select_option(
                                array(
                                  'label' => get_the_time('Y-m-d', $item->ID) . ' - ' . $name,
                                  'value' => $item->ID,
                                  'checked' => $selected
                                )
                            );
                        }
                    } else {
                        $name = ( strlen($item->post_title) > 38 ) ? mb_substr($item->post_title, 0, 35, 'UTF-8') . '&hellip;' : $item->post_title;
                        $selected = $escaped_value == $item->ID;
                        $options .= $field_type_object->select_option(
                            array(
                              'label' => get_the_time('Y-m-d', $item->ID) . ' - ' . $name,
                              'value' => $item->ID,
                              'checked' => $selected
                            )
                        );
                    }
                }
            }
        }
        echo $field_type_object->select(array('options' => $options));
    }

    add_action('cmb2_render_post_type_select', 'cmb2_render_post_type_select', 10, 5);
}

if (!function_exists('cmb2_render_post_type_multi_select')) {

    function cmb2_render_post_type_multi_select($field, $escaped_value, $object_id, $object_type, $field_type_object) {

        $term = isset($field_type_object->field->args['term']) ? $field_type_object->field->args['term'] : NULL;
        $taxonomy = isset($field_type_object->field->args['taxonomy']) ? $field_type_object->field->args['taxonomy'] : NULL;
        $post_type = isset($field_type_object->field->args['post_type']) ? $field_type_object->field->args['post_type'] : NULL;
        $args = array(
          $taxonomy => $term,
          'posts_per_page' => '-1',
          'post_type' => $post_type,
          'post_status' => array('publish', 'future'),
          'cache_results' => TRUE,
          'update_post_term_cache' => FALSE,
          'update_post_meta_cache' => FALSE,
          'no_found_rows' => TRUE,
          'fields' => 'ids',
          'suppress_filters' => '0',
        );
        $posts = get_posts($args);
        $options = '';

        foreach ($posts as $post_id) {
            $post_title = get_the_title($post_id);
            $name = ( strlen($post_title) > 38 ) ? mb_substr($post_title, 0, 35, 'UTF-8') . '...' : $post_title;
            $selected = ( is_array($escaped_value) && in_array($post_id, $escaped_value) ) ? $post_id : NULL;
            $options .= $field_type_object->select_option(
                array(
                  'label' => $name,
                  'value' => $post_id,
                  'checked' => $selected
                )
            );
        }
        echo $field_type_object->select(array(
          'options' => $options,
          'multiple' => 'multiple',
          'size' => '8',
          'name' => $field_type_object->field->args['id'] . '[]',
        ));
    }

    add_action('cmb2_render_post_type_multi_select', 'cmb2_render_post_type_multi_select', 10, 5);
}


if (!function_exists('cmb2_render_custom_post_type_multi_select')) {

    function cmb2_render_custom_post_type_multi_select($field, $escaped_value, $object_id, $object_type, $field_type_object) {

        $args = array(
          'public' => true
        );
        $post_types = get_post_types($args);
        $options = '';
        foreach ($post_types as $post_type) {
            $cpt_obj = get_post_type_object($post_type);
            $selected = ( is_array($escaped_value) && in_array($post_type, $escaped_value) ) ? $post_type : NULL;
            $options .= $field_type_object->select_option(
                array(
                  'label' => ucfirst($cpt_obj->labels->name),
                  'value' => $post_type,
                  'checked' => $selected
                )
            );
        }
        echo $field_type_object->select(array(
          'options' => $options,
          'multiple' => 'multiple',
          'size' => '8',
          'name' => $field_type_object->field->args['id'] . '[]',
        ));
    }

    add_action('cmb2_render_custom_post_type_multi_select', 'cmb2_render_custom_post_type_multi_select', 10, 5);
}

if (!function_exists('cmb2_render_post_type_select_link')) {

    function cmb2_render_post_type_select_link($field, $escaped_value, $object_id, $object_type, $field_type_object) {

        $term = isset($field_type_object->field->args['term']) ? $field_type_object->field->args['term'] : NULL;
        $taxonomy = isset($field_type_object->field->args['taxonomy']) ? $field_type_object->field->args['taxonomy'] : NULL;
        $post_type = isset($field_type_object->field->args['post_type']) ? $field_type_object->field->args['post_type'] : NULL;
        $args = array(
          $taxonomy => $term,
          'posts_per_page' => '-1',
          'post_type' => $post_type,
          'post_status' => array('publish', 'future'),
          'cache_results' => TRUE,
          'update_post_term_cache' => FALSE,
          'update_post_meta_cache' => FALSE,
          'no_found_rows' => TRUE,
          'fields' => 'ids',
          'suppress_filters' => '0',
        );
        $posts = get_posts($args);
        $options = $field_type_object->select_option(
            array(
              'label' => __('Please choose from list', 'green'),
              'value' => '',
              'checked' => ''
            )
        );

        foreach ($posts as $post_id) {
            $post_title = get_the_title($post_id);
            $name = ( strlen($post_title) > 38 ) ? mb_substr($post_title, 0, 35, 'UTF-8') . '...' : $post_title;
            $selected = $escaped_value == $post_id;
            $options .= $field_type_object->select_option(
                array(
                  'label' => $name,
                  'value' => $post_id,
                  'checked' => $selected
                )
            );
        }
        $url = NULL;
        if ($escaped_value) {
            $url = '<br/><a href="' . site_url() . '/wp-admin/post.php?post=' . $escaped_value . '&action=edit">' . get_the_title($escaped_value) . '</a>';
        }
        echo $field_type_object->select(array('options' => $options)) . $url;
    }

    add_action('cmb2_render_post_type_select_link', 'cmb2_render_post_type_select_link', 10, 5);
}

if (!function_exists('cmb2_render_text_list')) {

    function cmb2_render_text_list($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        $post_type = isset($field_type_object->field->args['post_type']) ? $field_type_object->field->args['post_type'] : NULL;
        $cmb_id = isset($field_type_object->field->args['id']) ? $field_type_object->field->args['id'] : NULL;
        $args = array(
          $taxonomy => $term,
          'posts_per_page' => '-1',
          'post_type' => $post_type,
          'post_status' => array('publish', 'future'),
          'cache_results' => TRUE,
          'update_post_term_cache' => FALSE,
          'update_post_meta_cache' => FALSE,
          'no_found_rows' => TRUE,
          'fields' => 'ids',
          'suppress_filters' => '0',
        );
        $posts = get_posts($args);
        $list = '<datalist id="' . $cmb_id . '-list">';
        $results = array();
        if ($posts) {
            foreach ($posts as $post_id) {
                $key = get_post_meta($post_id, $cmb_id, true);
                if ($key && $key != '') {
                    $results[$key] = $key;
                }
            }
        }
        foreach ($results as $key => $value) {
            $list .= '<option value="' . esc_attr($value) . '">' . $value . '</option>';
        }
        wp_reset_postdata();
        $list .= '</datalist>';
        echo $field_type_object->input(array('list' => $cmb_id . '-list', 'desc' => '', 'class' => 'list-text')) . $list;
    }

    add_action('cmb2_render_text_list', 'cmb2_render_text_list', 10, 5);
}

if (!function_exists('cmb2_render_of_forms')) {

    function cmb2_render_of_forms($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        if (function_exists('of_forms')) {
            $items = of_forms();
            if ($items && is_array($items)) {
                $options = $field_type_object->select_option(
                    array(
                      'label' => __('Please choose from list', 'green'),
                      'value' => '',
                      'checked' => ''
                    )
                );
                foreach ($items as $item_obj) {
                    $name = ( strlen($item_obj->title) > 38 ) ? mb_substr($item_obj->title, 0, 35, 'UTF-8') . '&hellip;' : $item_obj->title;
                    $selected = $escaped_value == $item_obj->ID;
                    $options .= $field_type_object->select_option(
                        array(
                          'label' => $name,
                          'value' => $item_obj->ID,
                          'checked' => $selected
                        )
                    );
                }
                echo $field_type_object->select(array('options' => $options));
            } else {
                echo __('Form selection is missing.', 'green');
            }
        } else {
            echo __('Form selection is missing.', 'green');
        }
    }

    add_action('cmb2_render_of_forms', 'cmb2_render_of_forms', 10, 5);
}

if (!function_exists('cmb2_render_of_projects')) {

    function cmb2_render_of_projects($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        if (function_exists('of_projects_stats')) {
            $items = of_projects_stats();
            if ($items && is_array($items)) {
                $options = $field_type_object->select_option(
                    array(
                      'label' => __('Please choose from list', 'green'),
                      'value' => '',
                      'checked' => ''
                    )
                );
                foreach ($items as $item_obj) {
                    $name = ( strlen($item_obj->title) > 38 ) ? mb_substr($item_obj->title, 0, 35, 'UTF-8') . '&hellip;' : $item_obj->title;
                    $selected = $escaped_value == $item_obj->ID;
                    $options .= $field_type_object->select_option(
                        array(
                          'label' => $name,
                          'value' => $item_obj->ID,
                          'checked' => $selected
                        )
                    );
                }
                echo $field_type_object->select(array('options' => $options));
            } else {
                echo __('Project selection is missing.', 'green');
            }
        } else {
            echo __('Project selection is missing.', 'green');
        }
    }

    add_action('cmb2_render_of_projects', 'cmb2_render_of_projects', 10, 5);
}

if (!function_exists('cmb2_render_of_events')) {

    function cmb2_render_of_events($field, $escaped_value, $object_id, $object_type, $field_type_object) {
        if (function_exists('of_events_stats')) {
            $items = of_events_stats();
            if ($items && is_array($items)) {
                $options = $field_type_object->select_option(
                    array(
                      'label' => __('Please choose from list', 'green'),
                      'value' => '',
                      'checked' => ''
                    )
                );
                foreach ($items as $item_obj) {
                    $name = ( strlen($item_obj->title) > 38 ) ? mb_substr($item_obj->title, 0, 35, 'UTF-8') . '&hellip;' : $item_obj->title;
                    $selected = $escaped_value == $item_obj->ID;
                    $options .= $field_type_object->select_option(
                        array(
                          'label' => $name,
                          'value' => $item_obj->ID,
                          'checked' => $selected
                        )
                    );
                }
                echo $field_type_object->select(array('options' => $options));
            } else {
                echo __('Event selection is missing.', 'green');
            }
        } else {
            echo __('Event selection is missing.', 'green');
        }
    }

    add_action('cmb2_render_of_events', 'cmb2_render_of_events', 10, 5);
}