<?php

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

    /*
     * CMB Field Type: Select2
     * https://github.com/mustardBees/cmb-field-select2
     */

/*
 * Use like so:

  $cmb_news->add_field( array(
  'name'    => 'Cooking time',
  'id'      => $prefix . 'cooking_time',
  'desc'    => 'Cooking time',
  'type'    => 'pw_select', // 'pw_multiselect',
  'options' => array(
  '5'  => '5 minutes',
  '10' => '10 minutes',
  '30' => 'Half an hour',
  '60' => '1 hour',
  ),
  ) );

 */

if (!function_exists('pw_select2_render')) {

    define('PW_SELECT2_VERSION', '2.0.4');

    function pw_select2_enqueue() {

        $dir = trailingslashit(dirname(__FILE__));

        if ('WIN' === strtoupper(substr(PHP_OS, 0, 3))) {
            // Windows
            $content_dir = str_replace('/', DIRECTORY_SEPARATOR, WP_CONTENT_DIR);
            $content_url = str_replace($content_dir, WP_CONTENT_URL, $dir);
            $url = str_replace(DIRECTORY_SEPARATOR, '/', $content_url);
        } else {
            $url = str_replace(
                array(WP_CONTENT_DIR, WP_PLUGIN_DIR), array(WP_CONTENT_URL, WP_PLUGIN_URL), $dir
            );
        }

        $url = set_url_scheme($url);

        wp_enqueue_script('pw-select2-field-js', $url . 'js/select2/select2.min.js', array('jquery-ui-sortable'), '3.5.1');
        wp_enqueue_script('pw-select2-field-init', $url . 'js/select2-init.js', array('pw-select2-field-js'), PW_SELECT2_VERSION);
        wp_enqueue_style('pw-select2-field-css', $url . 'js/select2/select2.css', array(), '3.5.1');
        wp_enqueue_style('pw-select2-field-mods', $url . 'css/select2.css', array(), PW_SELECT2_VERSION);
    }

    /**
     * Render select box field
     */
    function pw_select2_render($field, $value, $object_id, $object_type, $field_type_object) {
        pw_select2_enqueue();

        echo $field_type_object->select(array(
          'class' => 'cmb2_select select2',
          // Append an empty option (used by the placeholder)
          'options' => '<option></option>' . $field_type_object->concat_items(),
          // Use description as placeholder
          'desc' => $field->args('desc') && !empty($value) ? $field_type_object->_desc(true) : '',
          'data-placeholder' => $field->args('desc'),
        ));
    }

    add_filter('cmb2_render_pw_select', 'pw_select2_render', 10, 5);

    /**
     * Render multi-value select input field
     */
    function pw_multiselect_render($field, $value, $object_id, $object_type, $field_type_object) {
        pw_select2_enqueue();

        $options = array();

        foreach ((array) $field->options() as $opt_value => $opt_label) {
            $options[] = array(
              'id' => $opt_value,
              'text' => $opt_label
            );
        }

        wp_localize_script('pw-select2-field-init', $field_type_object->_id() . '_data', $options);

        echo $field_type_object->input(array(
          'type' => 'hidden',
          'class' => 'select2',
          // Use description as placeholder
          'desc' => $field->args('desc') && !empty($value) ? $field_type_object->_desc(true) : '',
          'data-placeholder' => esc_attr($field->args('description')),
        ));
    }

    add_filter('cmb2_render_pw_multiselect', 'pw_multiselect_render', 10, 5);

    function pw_multiselect_escape($check, $meta_value) {
        return !empty($meta_value) ? implode(',', $meta_value) : $check;
    }

    add_filter('cmb2_types_esc_pw_multiselect', 'pw_multiselect_escape', 10, 2);

    function pw_multiselect_sanitize($check, $meta_value) {

        if (!empty($meta_value)) {
            return explode(',', $meta_value);
        }

        return $check;
    }

    add_filter('cmb2_sanitize_pw_multiselect', 'pw_multiselect_sanitize', 10, 2);
}