<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

//  Get fundraising projects
if (!function_exists('of_projects_stats')) {

    function of_projects_stats($id = NULL, $return = NULL) {

        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }
        if (isset($options['of_fund_enable'])) {
            if (isset($options['of_fund_api']) && $options['of_fund_api'] != '') {

                $key = apply_filters('fragment_cache_prefix', 'gr_c_projects_stat');
                $output = get_transient($key);
                if (FALSE === $output) {

                    $content = @file_get_contents(of_fundraising_url() . '?get=projects&api=' . $options['of_fund_api']);
                    if ($content) {
                        $output = json_decode($content);
                        if (isset($output->error)) {
                            $output = $output->error;
                        }
                    } else {
                        $output = NULL;
                    }
                    set_transient($key, $output, '300');
                }

                if ($id) {
                    if (isset($output) && is_array($output)) {
                        foreach ($output as $project) {
                            if ($id == $project->ID) {
                                if ($return == 'status') {
                                    return ( isset($project->status) && $project->status != '' ) ? $project->status : NULL;
                                } elseif ($return == 'target') {
                                    return ( isset($project->target) && $project->target != '' ) ? $project->target : NULL;
                                } elseif ($return == 'offline') {
                                    return ( isset($project->offline) && $project->offline != '' ) ? $project->offline : NULL;
                                } else {
                                    return ( isset($project->title) && $project->title != '' ) ? $project->title : NULL;
                                }
                            }
                        }
                    }
                } else {
                    return $output;
                }
            }
        }
        return;
    }

}


//  Get fundraising stats
if (!function_exists('of_forms')) {

    function of_forms($id = NULL) {
        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }

        if (isset($options['of_fund_enable'])) {
            if (isset($options['of_fund_api']) && $options['of_fund_api'] != '') {

                $key = apply_filters('fragment_cache_prefix', 'gr_c_forms');
                $output = get_transient($key);
                if (FALSE === $output) {

                    $content = file_get_contents(of_fundraising_url() . '?get=forms&api=' . $options['of_fund_api']);
                    $output = json_decode($content);
                    if (isset($output->error)) {
                        $output = $output->error;
                    }
                    set_transient($key, $output, '300');
                }
            }
            if ($id) {
                if (isset($output) && is_array($output)) {
                    foreach ($output as $form) {
                        if ($id == $form->ID) {
                            return $form;
                        }
                    }
                }
            } else {
                return $output;
            }
        }
        return;
    }

}

//  Get fundraising stats
if (!function_exists('of_payments_stats')) {

    function of_payments_stats($id = NULL, $method = NULL) {
        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }
        if (isset($options['of_fund_enable'])) {
            if (isset($options['of_fund_api']) && $options['of_fund_api'] != '') {

                $key = apply_filters('fragment_cache_prefix', 'gr_c_payments_stat');
                $output = get_transient($key);
                if (FALSE === $output) {

                    $content = file_get_contents(of_fundraising_url() . '?get=payments&api=' . $options['of_fund_api']);
                    $output = json_decode($content);
                    if (isset($output->error)) {
                        $output = $output->error;
                    }
                    set_transient($key, $output, '300');
                }
                return $output;
            }
        }
        return;
    }

}

//  Get fundraising event stats
if (!function_exists('of_events_stats')) {

    function of_events_stats($id = NULL, $method = NULL) {
        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }
        if (isset($options['of_fund_enable'])) {
            if (isset($options['of_fund_api']) && $options['of_fund_api'] != '') {

                $key = apply_filters('fragment_cache_prefix', 'gr_c_events_stat');
                $output = get_transient($key);
                if (FALSE === $output) {

                    $content = file_get_contents(of_fundraising_url() . '?get=events&api=' . $options['of_fund_api']);
                    $output = json_decode($content);
                    if (isset($output->error)) {
                        $output = $output->error;
                    }
                    set_transient($key, $output, '300');
                }
                return $output;
            }
        }
        return;
    }

}

//  Get fundraising URL
if (!function_exists('of_fundraising_url')) {

    function of_fundraising_url() {
        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }
        $url = ( isset($options['of_fund_url']) && $options['of_fund_url'] != '' ) ? $options['of_fund_url'] : NULL;
        if ($url) {
            return $url;
        }
        return;
    }

}

//  Default payment page
if (!function_exists('of_payment_std')) {

    function of_payment_std() {
        $options = get_option('f2_fund');
        if (empty($options)) {
            $options = get_option('f2_premium');
        }
        $payment_std = NULL;
        if (isset($options['payment_std']) && $options['payment_std'] != '') {
            $payment_std = $options['payment_std'];
        } else {
            $payment_std = of_get_page_by_template('page-content-payment.php');
            if (empty($payment_std)) {
                $payment_std = of_get_page_by_shortcode('payment');
            }
        }
        return $payment_std;
    }

}

//  Detect page by Page Template
if (!function_exists('of_get_page_by_template')) {

    function of_get_page_by_template($template = NULL) {
        if (empty($template)) {
            return;
        }
        $args = array(
          'posts_per_page' => '1',
          'post_type' => 'page',
          'meta_key' => '_wp_page_template',
          'meta_value' => $template,
          'cache_results' => TRUE,
          'update_post_term_cache' => FALSE,
          'update_post_meta_cache' => FALSE,
          'no_found_rows' => TRUE,
          'fields' => 'ids'
        );
        $posts = get_posts($args);
        if ($posts) {
            return array_shift($posts);
        }
        return FALSE;
    }

}

//  Detect page by shortcode
if (!function_exists('of_get_page_by_shortcode')) {

    function of_get_page_by_shortcode($shortcode = NULL, $post_type = 'page') {
        if (empty($shortcode)) {
            return;
        }

        $key = apply_filters('fragment_cache_prefix', 'gr_c_shortcode' . $shortcode);
        $post_id = get_transient($key);
        if (FALSE === $post_id) {

            global $wpdb;
            $sql = 'SELECT ID
                FROM ' . $wpdb->posts . '
                WHERE
                    post_type = "' . $post_type . '"
                    AND post_status="publish"
                    AND post_content LIKE "%' . $shortcode . '%"';

            $post_id = $wpdb->get_var($sql);

            set_transient($key, $post_id, '86400');
        }

        return $post_id;
    }

}