<?php
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

/**
 * CMB2 Theme Options
 * https://github.com/WebDevStudios/CMB2-Snippet-Library/tree/master/options-and-settings-pages
 * @version 0.1.0
 */

class f2_fund_options_init {

    /**
     * Option key, and option page slug
     * @var string
     */
    private $key = 'f2_fund';

    /**
     * Options page metabox id
     * @var string
     */
    private $metabox_id = 'f2_fund_option_metabox';

    /**
     * Options Page title
     * @var string
     */
    protected $title = '';

    /**
     * Options Page hook
     * @var string
     */
    protected $options_page = '';

    /**
     * Constructor
     * @since 0.1.0
     */
    public function __construct() {
        $this->title = '';
    }

    /**
     * Initiate our hooks
     * @since 0.1.0
     */
    public function hooks() {
        add_action('admin_init', array($this, 'init'));
        add_action('admin_menu', array($this, 'add_options_page'));
        add_action('cmb2_admin_init', array($this, 'add_options_page_metabox'));
    }

    /**
     * Register our setting to WP
     * @since  0.1.0
     */
    public function init() {
        register_setting($this->key, $this->key);
    }

    /**
     * Add menu options page
     * @since 0.1.0
     */
    public function add_options_page() {

        $this->options_page = add_menu_page(
            __('Online Fundraising', 'flowtwo_fund'), __('Fundraising', 'flowtwo_fund'), 'manage_options', $this->key, array($this, 'admin_page_display'), 'dashicons-chart-area'
        );

        // Include CMB CSS in the head to avoid FOUT
        add_action("admin_print_styles-{$this->options_page}", array('CMB2_hookup', 'enqueue_cmb_css'));
    }

    /**
     * Admin page markup. Mostly handled by CMB2
     * @since  0.1.0
     */
    public function admin_page_display() {
        ?>
        <div class="wrap cmb2-options-page <?php echo $this->key; ?>">
            <h2><?php echo esc_html(get_admin_page_title()); ?></h2>
            <?php cmb2_metabox_form($this->metabox_id, $this->key); ?>
        </div>
        <?php
    }

    /**
     * Add the options metabox to the array of metaboxes
     * @since  0.1.0
     */
    function add_options_page_metabox() {

        $cmb = new_cmb2_box(array(
          'id' => $this->metabox_id,
          'hookup' => false,
          'cmb_styles' => false,
          'show_on' => array(
            // These are important, don't remove
            'key' => 'options-page',
            'value' => array($this->key,)
          ),
        ));

        // Set our CMB2 fields

        $cmb->add_field(array(
          'name' => __('Apply Online Fundraising', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'of_fund_enable',
          'type' => 'checkbox'
        ));

        $cmb->add_field(array(
          'name' => __('API key', 'flowtwo_fund'),
          'desc' => __('API key given by Online Fundraising', 'flowtwo_fund'),
          'id' => 'of_fund_api',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => 'phWHWpV97b8EfykGg6a',
          ),
        ));

        $cmb->add_field(array(
          'name' => __('MD5 Secret', 'flowtwo_fund'),
          'desc' => __('Secret entered at Online Fundraising', 'flowtwo_fund'),
          'id' => 'of_fund_md5',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => '7m3jcF2vyZktvmwUsq4',
          ),
        ));

        $cmb->add_field(array(
          'name' => __('Client URL', 'flowtwo_fund'),
          'desc' => __('Your URL at Online Fundraising', 'flowtwo_fund'),
          'id' => 'of_fund_url',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => 'https:/onlinefundraising.dk/' . __('yourname', 'flowtwo_fund'),
          ),
        ));

        $cmb->add_field(array(
          'name' => __('Defaults', 'flowtwo_fund'),
          'id' => 'of_defaults_title',
          'type' => 'title',
        ));

        $cmb->add_field(array(
          'name' => __('Select payment page', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'payment_std',
          'type' => 'post_type_select',
          'post_type' => 'page',
        ));

        $cmb->add_field(array(
          'name' => __('Payment button', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'payment_btn',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => __('Donate', 'flowtwo_fund')
          ),
        ));

        $cmb->add_field(array(
          'name' => __('Description of small payment form', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'payment_pre_desc',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => __('Insert your donation amount here', 'flowtwo_fund')
          ),
        ));

        $cmb->add_field(array(
          'name' => __('Tracking', 'flowtwo_fund'),
          'id' => 'of_tracking_title',
          'type' => 'title',
        ));

        $cmb->add_field(array(
          'name' => __('With Online Fundraising', 'flowtwo_fund'),
          'desc' => __('Apply by thicking this fields. Afterwards Online Fundraising will automatically pull data on visitors and donors', 'flowtwo_fund'),
          'id' => 'of_tracking',
          'type' => 'checkbox'
        ));

        $cmb->add_field(array(
          'name' => __('With Google Analytics', 'flowtwo_fund'),
          'desc' => __('Apply by entering tracking ID given by Google Analytics', 'flowtwo_fund'),
          'id' => 'ga_account',
          'type' => 'text',
          'attributes' => array(
            'placeholder' => 'UA-XXXX-Y'
          ),
        ));

        $cmb->add_field(array(
          'name' => __('Styling', 'flowtwo_fund'),
          'id' => 'of_styling_title',
          'type' => 'title',
        ));

        $cmb->add_field(array(
          'name' => __('Apply plugin stylesheet', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'of_fund_css',
          'type' => 'checkbox'
        ));

        $cmb->add_field(array(
          'name' => __('Customise plugin stylesheet', 'flowtwo_fund'),
          'desc' => '',
          'id' => 'of_fund_css_custom',
          'type' => 'textarea'
        ));
    }

    /**
     * Public getter method for retrieving protected/private variables
     * @since  0.1.0
     * @param  string  $field Field to retrieve
     * @return mixed          Field value or exception is thrown
     */
    public function __get($field) {
        // Allowed fields to retrieve
        if (in_array($field, array('key', 'metabox_id', 'title', 'options_page'), true)) {
            return $this->{$field};
        }

        throw new Exception('Invalid property: ' . $field);
    }

}

/**
 * Helper function to get/return the Myprefix_Admin object
 * @since  0.1.0
 * @return Myprefix_Admin object
 */
function f2_fund_options_admin() {
    static $object = null;
    if (is_null($object)) {
        $object = new f2_fund_options_init();
        $object->hooks();
    }

    return $object;
}

/**
 * Wrapper function around cmb2_get_option
 * @since  0.1.0
 * @param  string  $key Options array key
 * @return mixed        Option value
 */
function f2_fund_option($key = '') {
    if (function_exists('cmb2_get_option')) {
        return cmb2_get_option(f2_fund_options_admin()->key, $key);
    } else {
        $f2_fund_options = get_option('f2_fund');
        if (isset($f2_fund_options[$key]) && $f2_fund_options[$key] != '') {
            return $f2_fund_options[$key];
        }
    }
}

// Get it started
f2_fund_options_admin();
