<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

//  Shorthand array value detection
function of_esc_value($array = array(), $key = NULL, $default = NULL) {
    if (empty($array) || !is_array($array) || empty($key)) {
        return $default;
    }
    $return = isset($array[$key]) && $array[$key] != '' ? $array[$key] : $default;

    return $return;
}

//  Shorthand booloan detection
function of_esc_boolean($array = array(), $key = NULL) {
    if (empty($array) || empty($key)) {
        return FALSE;
    }
    $return = isset($array[$key]) && $array[$key] != '' ? TRUE : FALSE;

    return $return;
}

//  Customise numberformat
function of_number_format($number = NULL) {
    if (empty($number)) {
        return '0';
    } elseif (is_array($number)) {
        return;
    }
    return number_format($number, 0, ",", ".");
}

//  Stylesheet
function of_enqueue_style_css() {
    $options = get_option('f2_fund');
    if (isset($options['of_fund_css']) && !function_exists('of_enqueue_style_css')) {
        wp_enqueue_style('fundraising', F2_FUND_URL . 'lib/css/style.min.css', array(), '1.6');
    }
}

add_action('wp_enqueue_scripts', 'of_enqueue_style_css');

//  Custom styling
function of_enqueue_style_css_custom() {
    $options = get_option('f2_fund');
    if (isset($options['of_fund_css_custom']) && $options['of_fund_css_custom'] != '') {
        echo '<style type="text/css" media="all" id="of_style">' . $options['of_fund_css_custom'] . '</style>';
    }
}

add_action('wp_head', 'of_enqueue_style_css_custom');

//  Get currency by code
function of_get_currency($code) {
    switch ($code) {
        case '036' : return 'AED';
            break;
        case '124' : return 'CAD';
            break;
        case '208' : return 'DKK';
            break;
        case '344' : return 'HKD';
            break;
        case '352' : return 'ISK';
            break;
        case '392' : return 'JPY';
            break;
        case '484' : return 'MXN';
            break;
        case '554' : return 'NZD';
            break;
        case '578' : return 'NOK';
            break;
        case '702' : return 'SGD';
            break;
        case '710' : return 'ZAR';
            break;
        case '752' : return 'SEK';
            break;
        case '756' : return 'CHF';
            break;
        case '826' : return 'GBP';
            break;
        case '840' : return 'USD';
            break;
        case '949' : return 'TRY';
            break;
        case '978' : return 'EUR';
            break;
        case '985' : return 'PLN';
            break;
    }
    return 'DKK';
}
